@@ -8,6 +8,8 @@ archives, web assets, or a local file path.
 """
 
 import os
+import itertools
+
 from . import util
 
 # URL parsing for remote resources via WebResolver
@@ -50,16 +52,22 @@ class FilePathResolver(Resolver):
           File path where mesh was loaded from
         """
         # remove everything other than absolute path
-        clean = os.path.expanduser(os.path.abspath(str(source)))
+        clean = os.path.expanduser(
+            os.path.abspath(str(source)))
 
+        self.clean = clean
         if os.path.isdir(clean):
+            # if we were passed a directory use it
             self.parent = clean
-        # get the parent directory of the
-        elif os.path.isfile(clean):
+        else:
+            # otherwise get the parent directory we've been passed
             split = os.path.split(clean)
             self.parent = split[0]
-        else:
-            raise ValueError('path not a file or directory!')
+
+        # exit if directory doesn't exist
+        if not os.path.isdir(self.parent):
+            raise ValueError('path `{} `not a directory!'.format(
+                self.parent))
 
     def get(self, name):
         """
@@ -76,7 +84,11 @@ class FilePathResolver(Resolver):
           Loaded data from asset
         """
         # load the file by path name
-        with open(os.path.join(self.parent, name.strip()), 'rb') as f:
+        path = os.path.join(self.parent, name.strip())
+        if not os.path.exists(path):
+            path = os.path.join(
+                self.parent, os.path.split(name)[-1])
+        with open(path, 'rb') as f:
             data = f.read()
         return data
 
@@ -128,24 +140,26 @@ class ZipResolver(Resolver):
         data : bytes
           Loaded data from asset
         """
-        # not much we can do with that
+        # not much we can do with None
         if name is None:
             return
+        # make sure name is a string
+        if hasattr(name, 'decode'):
+            name = name.decode('utf-8')
+        # store reference to archive inside this function
+        archive = self.archive
 
-        # if name isn't in archive try some similar values
-        if name not in self.archive:
-            if hasattr(name, 'decode'):
-                name = name.decode('utf-8')
-            # try with cleared whitespace, split paths
-            for option in [name,
-                           name.lstrip('./'),
-                           name.strip(),
-                           name.split('/')[-1]]:
-                if option in self.archive:
+        # requested name not identical in storage so attempt to recover
+        if name not in archive:
+            # loop through unique results
+            for option in nearby_names(name):
+                if option in archive:
+                    # cleaned option is in archive so store value and exit
                     name = option
                     break
+
         # get the stored data
-        obj = self.archive[name]
+        obj = archive[name]
         # if the dict is storing data as bytes just return
         if isinstance(obj, (bytes, str)):
             return obj
@@ -221,3 +235,50 @@ class WebResolver(Resolver):
 
         # return the bytes of the response
         return response.content
+
+
+def nearby_names(name):
+    """
+    Try to find nearby variants of a specified name.
+
+    Parameters
+    ------------
+    name : str
+      Initial name.
+
+    Yields
+    -----------
+    nearby : str
+      Name that is a lightly permutated version of initial name.
+    """
+    # the various operations that *might* result in a correct key
+    cleaners = [lambda x: x,
+                lambda x: x.strip(),
+                lambda x: x.lstrip('./'),
+                lambda x: os.path.split(x)[-1],
+                lambda x: x.replace('%20', ' ')]
+
+    # make sure we don't return repeat values
+    hit = set()
+    for f in cleaners:
+        # try just one cleaning function
+        current = f(name)
+        if current in hit:
+            continue
+        hit.add(current)
+        yield current
+
+    for a, b in itertools.combinations(cleaners, 2):
+        # apply both clean functions
+        current = a(b(name))
+        if current in hit:
+            continue
+        hit.add(current)
+        yield current
+
+        # try applying in reverse order
+        current = b(a(name))
+        if current in hit:
+            continue
+        hit.add(current)
+        yield current
